@@ -25,8 +25,7 @@ class RecursiveRefKeyword_2019_09(Keyword):
     def resolve(self) -> None:
         if (base_uri := self.parentschema.base_uri) is not None:
             self.refschema = self.parentschema.catalogue.get_schema(
-                base_uri,
-                metaschema_uri=self.parentschema.metaschema_uri,
+                base_uri, metaschema_uri=self.parentschema.metaschema_uri, session=self.parentschema.session
             )
         else:
             raise JSONSchemaError(f'No base URI against which to resolve "$recursiveRef"')
